# Handshake 🫱🏾‍🫲🏼
_A Modern Test Reporter_

Processes the data collected from the test execution and then generates a modern Dashboard.

## Getting Started

### WebdriverIO

[WebdriverIO](https://webdriver.io/) is a Next-gen browser and mobile automation test framework for Node.js

1. Install Packages: `npm install wdio-handshake-reporter`
2. Install Dashboard: `npm install handshake`
3. Once done you can configure the reporter in your configuration.

## Plans
below are the things I would like to implement sooner or later.

* [X] Add support for `webdriverio`
* [ ] Add Reporter for `jest`
* [ ] Work on documentation
* [ ] Support for `mocha`
* [ ] Listen to `cypress` results
* [ ] Add Support for `playwright`

## Sample Shots